@@ -59,9 +59,9 @@ class SetupReproParameters(NamedTuple):
     """
 
     edition: str
-    platform: str
+    platform: Optional[str]
     architecture: str
-    variant: str
+    variant: Optional[str]
 
     versions: List[str]
     install_last_lts: bool
@@ -180,20 +180,32 @@ class SetupReproOrchestrator:
 
     @staticmethod
     def _get_bin_suffix(version: str, evg_project_id: str) -> str:
-        """Get the multiversion bin suffix from the evergreen project ID."""
+        """
+        Get the multiversion bin suffix from the evergreen project ID.
+
+        :param version: Version from the cmdline.
+        :param evg_project_id: Evergreen project ID.
+        :return: Bin suffix.
+        """
         if re.match(r"(\d+\.\d+)", version):
             # If the cmdline version is already a semvar, just use that.
             return version
-        elif evg_project_id in ("mongodb-mongo-master", "mongodb-mongo-master-nightly"):
-            # If the version is not a semvar and the project is the master waterfall,
-            # we can't add a suffix.
-            return ""
-        else:
-            # Use the Evergreen project ID as fallback.
-            return re.search(r"(\d+\.\d+$)", evg_project_id).group(0)
+
+        project_version_search = re.search(r"(\d+\.\d+$)", evg_project_id)
+        if project_version_search:
+            # Extract version from the Evergreen project ID as fallback.
+            return project_version_search.group(0)
+
+        # If the version is not a semvar, we can't add a suffix.
+        return ""
 
     def execute(self, setup_repro_params: SetupReproParameters) -> bool:
-        """Execute setup repro env mongodb."""
+        """
+        Execute setup repro env mongodb.
+
+        :param setup_repro_params: Setup repro env parameters.
+        :return: Whether succeeded or not.
+        """
         request_list = self.interpret_requests(
             setup_repro_params.versions,
             setup_repro_params.install_last_lts,
